@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2002 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2005 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,10 @@
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkstatusbar.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkvbbox.h>
+#include <gtk/gtkstock.h>
 
 #include "mgutils.h"
 #include "addressbook.h"
@@ -58,6 +62,7 @@ static struct _AddressEdit_dlg {
 static struct _PersonEdit_dlg {
 	GtkWidget *window;
 	GtkWidget *notebook;
+	GtkWidget *hbbox;
 	GtkWidget *ok_btn;
 	GtkWidget *cancel_btn;
 	GtkWidget *statusbar;
@@ -687,6 +692,7 @@ static void addressbook_edit_person_dialog_create( gboolean *cancelled ) {
 
 	personeditdlg.window     = window;
 	personeditdlg.notebook   = notebook;
+	personeditdlg.hbbox      = hbbox;
 	personeditdlg.ok_btn     = ok_btn;
 	personeditdlg.cancel_btn = cancel_btn;
 	personeditdlg.statusbar  = statusbar;
@@ -738,9 +744,9 @@ void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 	ATTACH_ROW(_("Display Name"), entry_name);
 	locale = conv_get_current_locale();
 	if (locale &&
-	    (!g_strncasecmp(locale, "ja", 2) ||
-	     !g_strncasecmp(locale, "ko", 2) ||
-	     !g_strncasecmp(locale, "zh", 2))) {
+	    (!g_ascii_strncasecmp(locale, "ja", 2) ||
+	     !g_ascii_strncasecmp(locale, "ko", 2) ||
+	     !g_ascii_strncasecmp(locale, "zh", 2))) {
 		ATTACH_ROW(_("Last Name"), entry_ln);
 		ATTACH_ROW(_("First Name"), entry_fn);
 	} else {
@@ -1094,6 +1100,8 @@ ItemPerson *addressbook_edit_person( AddressBookFile *abf, ItemFolder *parent, I
 
 	if (!personeditdlg.window)
 		addressbook_edit_person_create(&cancelled);
+	gtkut_box_set_reverse_order(GTK_BOX(personeditdlg.hbbox),
+				    !prefs_common.comply_gnome_hig);
 	gtk_widget_grab_focus(personeditdlg.ok_btn);
 	gtk_widget_grab_focus(personeditdlg.entry_name);
 	gtk_widget_show(personeditdlg.window);
