@@ -204,8 +204,8 @@ MimeView *mimeview_create(void)
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
 	gtk_tree_view_enable_model_drag_source
-		(GTK_TREE_VIEW(treeview), 0, mimeview_mime_types, 1,
-		 GDK_ACTION_COPY);
+		(GTK_TREE_VIEW(treeview), GDK_BUTTON1_MASK,
+		 mimeview_mime_types, 1, GDK_ACTION_COPY);
 
 	g_signal_connect(G_OBJECT(selection), "changed",
 			 G_CALLBACK(mimeview_selection_changed), mimeview);
