@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2004 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2005 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -151,6 +151,7 @@ static FolderClass news_class =
 	news_close,
 	news_scan_group,
 
+	NULL,
 	NULL,
 	NULL,
 	NULL
@@ -315,10 +316,13 @@ static GSList *news_get_article_list(Folder *folder, FolderItem *item,
 		cache_last = procmsg_get_last_num_in_msg_list(alist);
 		newlist = news_get_uncached_articles
 			(session, item, cache_last, &first, &last);
+		if (newlist)
+			item->cache_dirty = TRUE;
 		if (first == 0 && last == 0) {
 			news_delete_all_articles(item);
 			procmsg_msg_list_free(alist);
 			alist = NULL;
+			item->cache_dirty = TRUE;
 		} else {
 			alist = news_delete_old_articles(alist, item, first);
 			news_delete_expired_caches(alist, item);
@@ -334,12 +338,16 @@ static GSList *news_get_article_list(Folder *folder, FolderItem *item,
 			(session, item, 0, NULL, &last);
 		news_delete_all_articles(item);
 		item->last_num = last;
+		item->cache_dirty = TRUE;
 	}
 
 	procmsg_set_flags(alist, item);
 
 	alist = procmsg_sort_msg_list(alist, item->sort_key, item->sort_type);
 
+	debug_print("cache_dirty: %d, mark_dirty: %d\n",
+		    item->cache_dirty, item->mark_dirty);
+
 	return alist;
 }
 
@@ -497,7 +505,7 @@ static void news_group_info_free(NewsGroupInfo *ginfo)
 static gint news_group_info_compare(NewsGroupInfo *ginfo1,
 				    NewsGroupInfo *ginfo2)
 {
-	return g_strcasecmp(ginfo1->name, ginfo2->name);
+	return g_ascii_strcasecmp(ginfo1->name, ginfo2->name);
 }
 
 GSList *news_get_group_list(Folder *folder)
@@ -718,7 +726,8 @@ static gint news_select_group(NNTPSession *session, const gchar *group,
 	gint num_, first_, last_;
 
 	if (!num || !first || !last) {
-		if (session->group && g_strcasecmp(session->group, group) == 0)
+		if (session->group &&
+		    g_ascii_strcasecmp(session->group, group) == 0)
 			return NN_SUCCESS;
 		num = &num_;
 		first = &first_;
@@ -747,6 +756,7 @@ static GSList *news_get_uncached_articles(NNTPSession *session,
 	GSList *newlist = NULL;
 	GSList *llast = NULL;
 	MsgInfo *msginfo;
+	gint max_articles;
 
 	if (rfirst) *rfirst = -1;
 	if (rlast)  *rlast  = -1;
@@ -754,6 +764,7 @@ static GSList *news_get_uncached_articles(NNTPSession *session,
 	g_return_val_if_fail(session != NULL, NULL);
 	g_return_val_if_fail(item != NULL, NULL);
 	g_return_val_if_fail(item->folder != NULL, NULL);
+	g_return_val_if_fail(item->folder->account != NULL, NULL);
 	g_return_val_if_fail(FOLDER_TYPE(item->folder) == F_NEWS, NULL);
 
 	ok = news_select_group(session, item->path, &num, &first, &last);
@@ -786,9 +797,9 @@ static GSList *news_get_uncached_articles(NNTPSession *session,
 		begin = cache_last + 1;
 	end = last;
 
-	if (prefs_common.max_articles > 0 &&
-	    end - begin + 1 > prefs_common.max_articles)
-		begin = end - prefs_common.max_articles + 1;
+	max_articles = item->folder->account->max_nntp_articles;
+	if (max_articles > 0 && end - begin + 1 > max_articles)
+		begin = end - max_articles + 1;
 
 	log_message(_("getting xover %d - %d in %s...\n"),
 		    begin, end, item->path);
@@ -1014,6 +1025,7 @@ static GSList *news_delete_old_articles(GSList *alist, FolderItem *item,
 		if (msginfo && msginfo->msgnum < first) {
 			procmsg_msginfo_free(msginfo);
 			alist = g_slist_remove(alist, msginfo);
+			item->cache_dirty = TRUE;
 		}
 
 		cur = next;
