@@ -56,8 +56,8 @@ gint procheader_get_one_field(gchar *buf, size_t len, FILE *fp,
 
 			for (hp = hentry, hnum = 0; hp->name != NULL;
 			     hp++, hnum++) {
-				if (!strncasecmp(hp->name, buf,
-						 strlen(hp->name)))
+				if (!g_ascii_strncasecmp(hp->name, buf,
+							 strlen(hp->name)))
 					break;
 			}
 		} while (hp->name == NULL);
@@ -288,7 +288,7 @@ gint procheader_find_header_list(GSList *hlist, const gchar *header_name)
 
 	for (cur = hlist; cur != NULL; cur = cur->next, index++) {
 		header = (Header *)cur->data;
-		if (g_strcasecmp(header->name, header_name) == 0)
+		if (g_ascii_strcasecmp(header->name, header_name) == 0)
 			return index;
 	}
 
@@ -405,8 +405,8 @@ void procheader_get_header_fields(FILE *fp, HeaderEntry hentry[])
 
 		if (hp->body == NULL)
 			hp->body = g_strdup(p);
-		else if (!strcasecmp(hp->name, "To:") ||
-			 !strcasecmp(hp->name, "Cc:")) {
+		else if (!g_ascii_strcasecmp(hp->name, "To:") ||
+			 !g_ascii_strcasecmp(hp->name, "Cc:")) {
 			gchar *tp = hp->body;
 			hp->body = g_strconcat(tp, ", ", p, NULL);
 			g_free(tp);
@@ -584,7 +584,7 @@ MsgInfo *procheader_parse_stream(FILE *fp, MsgFlags flags, gboolean full)
 			}
 			break;
 		case H_CONTENT_TYPE:
-			if (!g_strncasecmp(hp, "multipart", 9)) {
+			if (!g_ascii_strncasecmp(hp, "multipart", 9)) {
 				MSG_SET_TMP_FLAGS(msginfo->flags, MSG_MIME);
 			} else if (!charset) {
 				procmime_scan_content_type_str
@@ -736,7 +736,6 @@ time_t procheader_date_parse(gchar *dest, const gchar *src, gint len)
 
 	if (procheader_scan_date_string(src, weekday, &day, month, &year,
 					&hh, &mm, &ss, zone) < 0) {
-		g_warning("Invalid date: %s\n", src);
 		if (dest && len > 0)
 			strncpy2(dest, src, len);
 		return 0;
@@ -752,13 +751,11 @@ time_t procheader_date_parse(gchar *dest, const gchar *src, gint len)
 
 	month[3] = '\0';
 	for (p = monthstr; *p != '\0'; p += 3) {
-		if (!strncasecmp(p, month, 3)) {
+		if (!g_ascii_strncasecmp(p, month, 3)) {
 			dmonth = (gint)(p - monthstr) / 3 + 1;
 			break;
 		}
 	}
-	if (*p == '\0')
-		g_warning("Invalid month: %s\n", month);
 
 	t.tm_sec = ss;
 	t.tm_min = mm;
@@ -771,6 +768,12 @@ time_t procheader_date_parse(gchar *dest, const gchar *src, gint len)
 	t.tm_isdst = -1;
 
 	timer = mktime(&t);
+	if (timer == -1) {
+		if (dest)
+			dest[0] = '\0';
+		return 0;
+	}
+
 	tz_offset = remote_tzoffset_sec(zone);
 	if (tz_offset != -1)
 		timer += tzoffset_sec(&timer) - tz_offset;
@@ -790,6 +793,11 @@ void procheader_date_get_localtime(gchar *dest, gint len, const time_t timer)
 	Xalloca(tmp, len + 1, dest[0] = '\0'; return;);
 
 	lt = localtime(&timer);
+	if (!lt) {
+		g_warning("can't get localtime of %d\n", timer);
+		dest[0] = '\0';
+		return;
+	}
 
 	if (prefs_common.date_format)
 		strftime(tmp, len, prefs_common.date_format, lt);
