@@ -197,7 +197,10 @@ MimeInfo *procmime_scan_message(MsgInfo *msginfo)
 #endif
 
 	if (mimeinfo) {
-		mimeinfo->size = get_left_file_size(fp);
+		mimeinfo->size = msginfo->size;
+		mimeinfo->content_size = get_left_file_size(fp);
+		if (mimeinfo->encoding_type == ENC_BASE64)
+			mimeinfo->content_size = mimeinfo->content_size / 4 * 3;
 		if (mimeinfo->mime_type == MIME_MULTIPART ||
 		    mimeinfo->mime_type == MIME_MESSAGE_RFC822)
 			procmime_scan_multipart_message(mimeinfo, fp);
@@ -248,17 +251,23 @@ void procmime_scan_multipart_message(MimeInfo *mimeinfo, FILE *fp)
 	for (;;) {
 		MimeInfo *partinfo;
 		gboolean eom = FALSE;
+		glong content_pos;
+		gboolean is_base64;
 		gint len;
+		guint b64_content_len = 0;
+		gint b64_pad_len = 0;
 
 		prev_fpos = fpos;
 		debug_print("prev_fpos: %ld\n", fpos);
 
+		/* scan part header */
 		if (mimeinfo->mime_type == MIME_MESSAGE_RFC822) {
 			MimeInfo *sub;
 
 			mimeinfo->sub = sub = procmime_scan_mime_header(fp);
 			if (!sub) break;
 
+			debug_print("message/rfc822 part found\n");
 			sub->level = mimeinfo->level + 1;
 			sub->parent = mimeinfo->parent;
 			sub->main = mimeinfo;
@@ -272,6 +281,10 @@ void procmime_scan_multipart_message(MimeInfo *mimeinfo, FILE *fp)
 				    partinfo->content_type);
 		}
 
+		/* begin content */
+		content_pos = ftell(fp);
+		debug_print("content_pos: %ld\n", content_pos);
+
 		if (partinfo->mime_type == MIME_MULTIPART ||
 		    partinfo->mime_type == MIME_MESSAGE_RFC822) {
 			if (partinfo->level < 8)
@@ -280,12 +293,20 @@ void procmime_scan_multipart_message(MimeInfo *mimeinfo, FILE *fp)
 
 		/* look for next boundary */
 		buf[0] = '\0';
+		is_base64 = partinfo->encoding_type == ENC_BASE64;
 		while ((p = fgets(buf, sizeof(buf), fp)) != NULL) {
 			if (IS_BOUNDARY(buf, boundary, boundary_len)) {
 				if (buf[2 + boundary_len]     == '-' &&
 				    buf[2 + boundary_len + 1] == '-')
 					eom = TRUE;
 				break;
+			} else if (is_base64) {
+				const gchar *s;
+				for (s = buf; *s && *s != '\r' && *s != '\n';
+				     ++s)
+					if (*s == '=')
+						++b64_pad_len;
+				b64_content_len += s - buf;
 			}
 		}
 		if (p == NULL) {
@@ -300,7 +321,14 @@ void procmime_scan_multipart_message(MimeInfo *mimeinfo, FILE *fp)
 
 		len = strlen(buf);
 		partinfo->size = fpos - prev_fpos - len;
+		if (is_base64)
+			partinfo->content_size =
+				b64_content_len / 4 * 3 - b64_pad_len;
+		else
+			partinfo->content_size = fpos - content_pos - len;
 		debug_print("partinfo->size: %d\n", partinfo->size);
+		debug_print("partinfo->content_size: %d\n",
+			    partinfo->content_size);
 		if (partinfo->sub && !partinfo->sub->sub &&
 		    !partinfo->sub->children) {
 			partinfo->sub->size =
@@ -328,15 +356,15 @@ void procmime_scan_encoding(MimeInfo *mimeinfo, const gchar *encoding)
 	g_free(mimeinfo->encoding);
 
 	mimeinfo->encoding = g_strdup(g_strstrip(buf));
-	if (!strcasecmp(buf, "7bit"))
+	if (!g_ascii_strcasecmp(buf, "7bit"))
 		mimeinfo->encoding_type = ENC_7BIT;
-	else if (!strcasecmp(buf, "8bit"))
+	else if (!g_ascii_strcasecmp(buf, "8bit"))
 		mimeinfo->encoding_type = ENC_8BIT;
-	else if (!strcasecmp(buf, "quoted-printable"))
+	else if (!g_ascii_strcasecmp(buf, "quoted-printable"))
 		mimeinfo->encoding_type = ENC_QUOTED_PRINTABLE;
-	else if (!strcasecmp(buf, "base64"))
+	else if (!g_ascii_strcasecmp(buf, "base64"))
 		mimeinfo->encoding_type = ENC_BASE64;
-	else if (!strcasecmp(buf, "x-uuencode"))
+	else if (!g_ascii_strcasecmp(buf, "x-uuencode"))
 		mimeinfo->encoding_type = ENC_X_UUENCODE;
 	else
 		mimeinfo->encoding_type = ENC_UNKNOWN;
@@ -401,11 +429,12 @@ void procmime_scan_content_type_str(const gchar *content_type,
 		}
 
 		if (*value) {
-			if (charset && !g_strcasecmp(attr, "charset"))
+			if (charset && !g_ascii_strcasecmp(attr, "charset"))
 				*charset = g_strdup(value);
-			else if (name && !g_strcasecmp(attr, "name"))
+			else if (name && !g_ascii_strcasecmp(attr, "name"))
 				*name = conv_unmime_header(value, NULL);
-			else if (boundary && !g_strcasecmp(attr, "boundary"))
+			else if (boundary &&
+				 !g_ascii_strcasecmp(attr, "boundary"))
 				*boundary = g_strdup(value);
 		}
 
@@ -450,7 +479,7 @@ void procmime_scan_content_disposition(MimeInfo *mimeinfo,
 		}
 
 		if (*value) {
-			if (!strcasecmp(attr, "filename")) {
+			if (!g_ascii_strcasecmp(attr, "filename")) {
 				g_free(mimeinfo->filename);
 				mimeinfo->filename =
 					conv_unmime_header(value, NULL);
@@ -558,10 +587,12 @@ FILE *procmime_decode_content(FILE *outfp, FILE *infp, MimeInfo *mimeinfo)
 		Base64Decoder *decoder;
 		gboolean uncanonicalize = FALSE;
 		FILE *tmpfp = outfp;
+		ContentType content_type;
 
-		if (mimeinfo->mime_type == MIME_TEXT ||
-		    mimeinfo->mime_type == MIME_TEXT_HTML ||
-		    mimeinfo->mime_type == MIME_MESSAGE_RFC822) {
+		content_type = procmime_scan_mime_type(mimeinfo->content_type);
+		if (content_type == MIME_TEXT ||
+		    content_type == MIME_TEXT_HTML ||
+		    content_type == MIME_MESSAGE_RFC822) {
 			uncanonicalize = TRUE;
 			tmpfp = my_tmpfile();
 			if (!tmpfp) {
@@ -896,25 +927,26 @@ ContentType procmime_scan_mime_type(const gchar *mime_type)
 {
 	ContentType type;
 
-	if (!strncasecmp(mime_type, "text/html", 9))
+	if (!g_ascii_strncasecmp(mime_type, "text/html", 9))
 		type = MIME_TEXT_HTML;
-	else if (!strncasecmp(mime_type, "text/", 5))
+	else if (!g_ascii_strncasecmp(mime_type, "text/", 5))
 		type = MIME_TEXT;
-	else if (!strncasecmp(mime_type, "message/rfc822", 14))
+	else if (!g_ascii_strncasecmp(mime_type, "message/rfc822", 14))
 		type = MIME_MESSAGE_RFC822;
-	else if (!strncasecmp(mime_type, "message/", 8))
+	else if (!g_ascii_strncasecmp(mime_type, "message/", 8))
 		type = MIME_TEXT;
-	else if (!strncasecmp(mime_type, "application/octet-stream", 24))
+	else if (!g_ascii_strncasecmp(mime_type, "application/octet-stream",
+				      24))
 		type = MIME_APPLICATION_OCTET_STREAM;
-	else if (!strncasecmp(mime_type, "application/", 12))
+	else if (!g_ascii_strncasecmp(mime_type, "application/", 12))
 		type = MIME_APPLICATION;
-	else if (!strncasecmp(mime_type, "multipart/", 10))
+	else if (!g_ascii_strncasecmp(mime_type, "multipart/", 10))
 		type = MIME_MULTIPART;
-	else if (!strncasecmp(mime_type, "image/", 6))
+	else if (!g_ascii_strncasecmp(mime_type, "image/", 6))
 		type = MIME_IMAGE;
-	else if (!strncasecmp(mime_type, "audio/", 6))
+	else if (!g_ascii_strncasecmp(mime_type, "audio/", 6))
 		type = MIME_AUDIO;
-	else if (!strcasecmp(mime_type, "text"))
+	else if (!g_ascii_strcasecmp(mime_type, "text"))
 		type = MIME_TEXT;
 	else
 		type = MIME_UNKNOWN;
@@ -1063,14 +1095,14 @@ EncodingType procmime_get_encoding_for_charset(const gchar *charset)
 {
 	if (!charset)
 		return ENC_8BIT;
-	else if (!strncasecmp(charset, "ISO-2022-", 9) ||
-		 !strcasecmp(charset, "US-ASCII"))
+	else if (!g_ascii_strncasecmp(charset, "ISO-2022-", 9) ||
+		 !g_ascii_strcasecmp(charset, "US-ASCII"))
 		return ENC_7BIT;
-	else if (!strcasecmp(charset, "ISO-8859-5") ||
-		 !strncasecmp(charset, "KOI8-", 5) ||
-		 !strcasecmp(charset, "Windows-1251"))
+	else if (!g_ascii_strcasecmp(charset, "ISO-8859-5") ||
+		 !g_ascii_strncasecmp(charset, "KOI8-", 5) ||
+		 !g_ascii_strcasecmp(charset, "Windows-1251"))
 		return ENC_8BIT;
-	else if (!strncasecmp(charset, "ISO-8859-", 9))
+	else if (!g_ascii_strncasecmp(charset, "ISO-8859-", 9))
 		return ENC_QUOTED_PRINTABLE;
 	else
 		return ENC_8BIT;
